==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/CategoryToolTipLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { CategoryToolTipLayerDescription } from "./CategoryToolTipLayerDescription";
/**
 * @hidden
 */
var CategoryToolTipLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CategoryToolTipLayerDescriptionMetadata, _super);
    function CategoryToolTipLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryToolTipLayerDescriptionMetadata.b = function (a) {
        if (CategoryToolTipLayerDescriptionMetadata.a == null) {
            CategoryToolTipLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryToolTipLayerDescriptionMetadata.c(CategoryToolTipLayerDescriptionMetadata.a);
        }
        if (a.g(CategoryToolTipLayerDescriptionMetadata.a)) {
            return;
        }
        a.s(CategoryToolTipLayerDescriptionMetadata.a);
    };
    CategoryToolTipLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetAxisRef", "(w:TargetAxis,wf:TargetAxis)DataRef::object");
        a.item("UseInterpolation", "Boolean");
    };
    CategoryToolTipLayerDescriptionMetadata.d = function (a) {
        CategoryToolTipLayerDescriptionMetadata.b(a);
        a.u("CategoryToolTipLayer", function () { return new CategoryToolTipLayerDescription(); });
        a.t("CategoryToolTipLayer", CategoryToolTipLayerDescriptionMetadata.a);
    };
    CategoryToolTipLayerDescriptionMetadata.$t = markType(CategoryToolTipLayerDescriptionMetadata, 'CategoryToolTipLayerDescriptionMetadata');
    CategoryToolTipLayerDescriptionMetadata.a = null;
    return CategoryToolTipLayerDescriptionMetadata;
}(Base));
export { CategoryToolTipLayerDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/CategoryToolTipLayerDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AnnotationLayerDescriptionMetadata } from "./AnnotationLayerDescriptionMetadata";
import { CategoryToolTipLayerDescription } from "./CategoryToolTipLayerDescription";
/**
 * @hidden
 */
var CategoryToolTipLayerDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(CategoryToolTipLayerDescriptionMetadata, _super);
    function CategoryToolTipLayerDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CategoryToolTipLayerDescriptionMetadata.b = function (a) {
        if (CategoryToolTipLayerDescriptionMetadata.a == null) {
            CategoryToolTipLayerDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CategoryToolTipLayerDescriptionMetadata.c(CategoryToolTipLayerDescriptionMetadata.a);
        }
        if (a.j(CategoryToolTipLayerDescriptionMetadata.a)) {
            return;
        }
        a.y(CategoryToolTipLayerDescriptionMetadata.a);
    };
    CategoryToolTipLayerDescriptionMetadata.c = function (a) {
        AnnotationLayerDescriptionMetadata.c(a);
        a.item("TargetAxisRef", "(w:TargetAxis,wf:TargetAxis)DataRef::object");
        a.item("UseInterpolation", "Boolean");
    };
    CategoryToolTipLayerDescriptionMetadata.d = function (a) {
        CategoryToolTipLayerDescriptionMetadata.b(a);
        a.aa("CategoryToolTipLayer", function () { return new CategoryToolTipLayerDescription(); });
        a.z("CategoryToolTipLayer", CategoryToolTipLayerDescriptionMetadata.a);
    };
    CategoryToolTipLayerDescriptionMetadata.$t = markType(CategoryToolTipLayerDescriptionMetadata, 'CategoryToolTipLayerDescriptionMetadata');
    CategoryToolTipLayerDescriptionMetadata.a = null;
    return CategoryToolTipLayerDescriptionMetadata;
}(Base));
export { CategoryToolTipLayerDescriptionMetadata };
